@@ -130,7 +130,7 @@ class Device(Events):
                 os.mkdir(self.__ocr_mods)
             else:
                 if not Path(self.__ocr_mods).is_dir():
-                    os.remove(self.__ocr_mods)
+                    os.remove("./ocr_models")
                     os.mkdir(self.__ocr_mods)
             for mod in os.listdir(ocrCraftModel4uts.get_path()):
                 if not Path(ocrCraftModel4uts.get_path() + mod).is_dir():
@@ -141,7 +141,7 @@ class Device(Events):
                     if not Path(self.__ocr_mods + mod).exists():
                         shutil.copy(ocrLangModel4uts.get_path() + mod, self.__ocr_mods)
         self.refresh_layout()
-        if self.control_host_type != 0:
+        if self.control_host_type != Controller.ANYWHERE:
             self.webdriver = webdriver.WebDriver(command_executor='http://127.0.0.1:8910/wd/hub')
 
     def __check_platform(self):
@@ -452,12 +452,12 @@ class Device(Events):
         :param item: 传入的元素控件
         :return: TextItemFromOcr对象列表
         """
-        reader = easyocr.Reader(['ch_sim', 'en'], gpu=False, model_storage_directory=self.__ocr_mods)
         image_base64 = item.grab_image_to_base64()
         image = open("./orc_temp_image.png", "wb")
         imdata = base64.b64decode(image_base64)
         image.write(imdata)
         image.close()
+        reader = easyocr.Reader(['ch_sim', 'en'], gpu=False, model_storage_directory=self.__ocr_mods)
         im = Image.open(io.BytesIO(imdata))
         width, height = im.size
         px = item.center_x_to_global() - (width / 2)
