@@ -28,13 +28,9 @@ class Events:
     模拟事件类。
     """
     device = None
-    app = None
-    item = None
 
-    def __init__(self, d=None, a=None, i=None):
+    def __init__(self, d):
         self.device = d
-        self.app = a
-        self.item = i
 
     @staticmethod
     def __reply_status_check(reply):
